Tutorials — episcanpy 0.0.1 documentation

# Tutorials

## single cell ATAC

Currently, for getting started, we recommend Scanpy’s reimplementation of Seurat’s [Satija15] clustering tutorial 2700 PBMCs from 10x Genomics, containing preprocessing, clustering and the identification of cell types via known marker genes.

You might compare this to clustering 68K PBMCs as it would be done in Cell Ranger [Zheng17].

## Single cell methylation

For trajectory inference on complex datasets, we offer several examples here. Get started here for the following result on hematopoiesis.

You can extend this to multi-resolution analyses of whole animals, such as here.

The PAGA method behind this is described here and can be cited using this doi. As a reference for simple pseudotime analyses, we provide the diffusion pseudotime analyses of [Haghverdi16] for two hematopoiesis datasets: here for [Paul15] and here for [Moignard15].